@@ -1,4 +1,4 @@
-/* Copyright 2007-2009 Matthew Barnes
+/* Copyright 2007-2011 Matthew Barnes
  *
  * This file is part of GNOME Video Arcade.
  *
@@ -61,7 +61,8 @@ typedef struct _GvaInpHeaderSimple GvaInpHeaderSimple;
 typedef struct _GvaInpHeaderExtended GvaInpHeaderExtended;
 typedef struct _GvaInpHeaderVersioned GvaInpHeaderVersioned;
 
-enum {
+enum
+{
         PROP_0,
         PROP_FILENAME,
         PROP_FORMAT,
@@ -110,7 +111,10 @@ struct _GvaInpHeaderVersioned
         gchar origin[32];       /* MAME version string */
 };
 
-static gpointer parent_class = NULL;
+G_DEFINE_TYPE (
+        GvaInputFile,
+        gva_input_file,
+        G_TYPE_OBJECT)
 
 static void
 input_file_dump_header (GvaInputFile *input_file)
@@ -130,12 +134,12 @@ input_file_dump_header (GvaInputFile *input_file)
 
         inpname = g_strdelimit (g_path_get_basename (filename), ".", '\0');
 
-        g_debug ("Input file: %s", inpname);
-        g_debug ("Game: %s", game);
-        g_debug ("%s", format);
-        g_debug ("Created %s", ctime (&timestamp));
-        g_debug ("Recorded using %s", origin);
-        g_debug ("--");
+        g_log (G_LOG_DOMAIN, GVA_DEBUG_INP, "Input file: %s", inpname);
+        g_log (G_LOG_DOMAIN, GVA_DEBUG_INP, "Game: %s", game);
+        g_log (G_LOG_DOMAIN, GVA_DEBUG_INP, "%s", format);
+        g_log (G_LOG_DOMAIN, GVA_DEBUG_INP, "Created %s", ctime (&timestamp));
+        g_log (G_LOG_DOMAIN, GVA_DEBUG_INP, "Recorded using %s", origin);
+        g_log (G_LOG_DOMAIN, GVA_DEBUG_INP, "--");
 
         g_free (inpname);
 }
@@ -331,15 +335,14 @@ input_file_finalize (GObject *object)
         g_free (priv->origin);
 
         /* Chain up to parent's finalize() method. */
-        G_OBJECT_CLASS (parent_class)->finalize (object);
+        G_OBJECT_CLASS (gva_input_file_parent_class)->finalize (object);
 }
 
 static void
-input_file_class_init (GvaInputFileClass *class)
+gva_input_file_class_init (GvaInputFileClass *class)
 {
         GObjectClass *object_class;
 
-        parent_class = g_type_class_peek_parent (class);
         g_type_class_add_private (class, sizeof (GvaInputFilePrivate));
 
         object_class = G_OBJECT_CLASS (class);
@@ -361,7 +364,8 @@ input_file_class_init (GvaInputFileClass *class)
                         NULL,
                         NULL,
                         G_PARAM_READWRITE |
-                        G_PARAM_CONSTRUCT_ONLY));
+                        G_PARAM_CONSTRUCT_ONLY |
+                        G_PARAM_STATIC_STRINGS));
 
         /**
          * GvaInputFile:format:
@@ -376,7 +380,8 @@ input_file_class_init (GvaInputFileClass *class)
                         NULL,
                         NULL,
                         NULL,
-                        G_PARAM_READABLE));
+                        G_PARAM_READABLE |
+                        G_PARAM_STATIC_STRINGS));
 
         /**
          * GvaInputFile:game:
@@ -391,7 +396,8 @@ input_file_class_init (GvaInputFileClass *class)
                         NULL,
                         NULL,
                         NULL,
-                        G_PARAM_READABLE));
+                        G_PARAM_READABLE |
+                        G_PARAM_STATIC_STRINGS));
 
         /**
          * GvaInputFile:origin:
@@ -406,7 +412,8 @@ input_file_class_init (GvaInputFileClass *class)
                         NULL,
                         NULL,
                         NULL,
-                        G_PARAM_READABLE));
+                        G_PARAM_READABLE |
+                        G_PARAM_STATIC_STRINGS));
 
         /**
          * GvaInputFile:timestamp:
@@ -423,43 +430,16 @@ input_file_class_init (GvaInputFileClass *class)
                         G_MININT64,
                         G_MAXINT64,
                         0,
-                        G_PARAM_READABLE));
+                        G_PARAM_READABLE |
+                        G_PARAM_STATIC_STRINGS));
 }
 
 static void
-input_file_init (GvaInputFile *input_file)
+gva_input_file_init (GvaInputFile *input_file)
 {
         input_file->priv = GVA_INPUT_FILE_GET_PRIVATE (input_file);
 }
 
-GType
-gva_input_file_get_type (void)
-{
-        static GType type = 0;
-
-        if (G_UNLIKELY (type == 0))
-        {
-                static const GTypeInfo type_info =
-                {
-                        sizeof (GvaInputFileClass),
-                        (GBaseInitFunc) NULL,
-                        (GBaseFinalizeFunc) NULL,
-                        (GClassInitFunc) input_file_class_init,
-                        (GClassFinalizeFunc) NULL,
-                        NULL,  /* class_data */
-                        sizeof (GvaInputFile),
-                        0,     /* n_preallocs */
-                        (GInstanceInitFunc) input_file_init,
-                        NULL   /* value_table */
-                };
-
-                type = g_type_register_static (
-                        G_TYPE_OBJECT, "GvaInputFile", &type_info, 0);
-        }
-
-        return type;
-}
-
 /**
  * gva_input_file_new:
  * @filename: path to a MAME INP file
