@@ -1,4 +1,4 @@
-/* Copyright 2007-2009 Matthew Barnes
+/* Copyright 2007-2011 Matthew Barnes
  *
  * This file is part of GNOME Video Arcade.
  *
@@ -25,7 +25,8 @@
 #include "gva-error.h"
 #include "gva-game-store.h"
 #include "gva-history.h"
-#include "gva-link-button.h"
+#include "gva-music-button.h"
+#include "gva-preferences.h"
 #include "gva-tree-view.h"
 #include "gva-ui.h"
 #include "gva-util.h"
@@ -113,21 +114,13 @@ properties_scroll_to_top (void)
 }
 
 static void
-properties_label_clicked_cb (GvaLinkButton *button,
-                             const gchar *game)
+properties_link_clicked_cb (GtkLabel *label,
+                            const gchar *game)
 {
-        GdkEvent *event;
-	GtkWidget *widget;
+        GtkWidget *widget;
 
-        /* Force the cursor back to normal before the button is destroyed.
-         * XXX We're passing the wrong type of event here, but it should be
-         *     okay for this particular case. */
-        event = gtk_get_current_event ();
-        g_signal_emit_by_name (button, "leave-notify-event", event);
-        gdk_event_free (event);
-
-	widget = GVA_WIDGET_PROPERTIES_TECHNICAL_SCROLLED_WINDOW;
-	gtk_widget_grab_focus (widget);
+        widget = GVA_WIDGET_PROPERTIES_TECHNICAL_SCROLLED_WINDOW;
+        gtk_widget_grab_focus (widget);
 
         gva_properties_show_game (game);
         gva_tree_view_set_selected_game (game);
@@ -141,22 +134,27 @@ properties_add_game_label (GtkBox *box,
 {
         GtkWidget *widget;
 
+        widget = gtk_label_new (NULL);
+        gtk_misc_set_alignment (GTK_MISC (widget), 0.0, 0.5);
+
         if (available)
         {
-                widget = gva_link_button_new (description);
-                gtk_button_set_alignment (GTK_BUTTON (widget), 0.0, 0.5);
-                gtk_widget_set_tooltip_text (widget, _("Show this game"));
+                gchar *markup;
+
+                markup = g_markup_printf_escaped (
+                        "<a href=\"%s\" title=\"%s\">%s</a>",
+                        game, _("Show this game"), description);
+
+                gtk_label_set_markup (GTK_LABEL (widget), markup);
 
                 g_signal_connect (
-                        widget, "clicked",
-                        G_CALLBACK (properties_label_clicked_cb),
-                        (gpointer) g_intern_string (game));
+                        widget, "activate-link",
+                        G_CALLBACK (properties_link_clicked_cb), NULL);
+
+                g_free (markup);
         }
         else
-        {
-                widget = gtk_label_new (description);
-                gtk_misc_set_alignment (GTK_MISC (widget), 0.0, 0.5);
-        }
+                gtk_label_set_text (GTK_LABEL (widget), description);
 
         gtk_box_pack_start (box, widget, FALSE, FALSE, 0);
         gtk_widget_show (widget);
@@ -472,6 +470,19 @@ properties_update_history (GtkTreeModel *model,
 #endif
 }
 
+static void
+properties_update_music (const gchar *name)
+{
+        GvaMusicButton *music_button;
+
+        music_button = GVA_MUSIC_BUTTON (GVA_WIDGET_PROPERTIES_MUSIC_BUTTON);
+        gva_music_button_set_game (music_button, name);
+
+        if (gtk_widget_get_visible (GVA_WIDGET_PROPERTIES_WINDOW)
+                && gva_preferences_get_auto_play ())
+                gva_music_button_play (music_button);
+}
+
 static void
 properties_update_sound (const gchar *name)
 {
@@ -486,7 +497,8 @@ properties_update_sound (const gchar *name)
         sql = g_strdup_printf (
                 SQL_SELECT_SOUND, name, G_N_ELEMENTS (sound_labels));
 
-        if (!gva_db_get_table (sql, &result, &rows, &columns, &error)) {
+        if (!gva_db_get_table (sql, &result, &rows, &columns, &error))
+        {
                 gva_error_handle (&error);
                 rows = columns = 0;
         }
@@ -631,7 +643,8 @@ properties_update_video (const gchar *name)
         sql = g_strdup_printf (
                 SQL_SELECT_VIDEO, name, G_N_ELEMENTS (video_labels));
 
-        if (!gva_db_get_table (sql, &result, &rows, &columns, &error)) {
+        if (!gva_db_get_table (sql, &result, &rows, &columns, &error))
+        {
                 gva_error_handle (&error);
                 rows = columns = 0;
         }
@@ -722,6 +735,25 @@ properties_selection_changed_cb (GtkTreeSelection *selection)
                 properties_update_timeout_cb, NULL);
 }
 
+static void
+properties_notify_music_status_cb (GvaMusicButton *music_button)
+{
+        GtkWidget *label;
+        const gchar *status;
+        gchar *markup;
+
+        label = GVA_WIDGET_PROPERTIES_MUSIC_STATUS;
+        status = gva_music_button_get_status (music_button);
+
+        /* Use whitespace to keep the widget height stable. */
+        if (status == NULL)
+                status = " ";
+
+        markup = g_markup_printf_escaped ("<small>%s</small>", status);
+        gtk_label_set_markup (GTK_LABEL (label), markup);
+        g_free (markup);
+}
+
 /**
  * gva_properties_init:
  *
@@ -732,9 +764,9 @@ properties_selection_changed_cb (GtkTreeSelection *selection)
 void
 gva_properties_init (void)
 {
-        GtkWindow *window;
         GtkTreeView *view;
-        GtkSettings *settings;
+        GSettings *settings;
+        GtkSettings *gtk_settings;
         GtkWidget *text_view;
         GHashTable *color_hash;
         PangoFontDescription *desc;
@@ -746,40 +778,50 @@ gva_properties_init (void)
         GtkNotebook *notebook;
 #endif
 
-        window = GTK_WINDOW (GVA_WIDGET_PROPERTIES_WINDOW);
+        settings = gva_get_settings ();
+
         view = GTK_TREE_VIEW (GVA_WIDGET_MAIN_TREE_VIEW);
         text_view = GVA_WIDGET_PROPERTIES_HISTORY_TEXT_VIEW;
 
-        gtk_action_connect_proxy (
-                GVA_ACTION_PREVIOUS_GAME,
-                GVA_WIDGET_PROPERTIES_BACK_BUTTON);
-
-        gtk_action_connect_proxy (
-                GVA_ACTION_NEXT_GAME,
-                GVA_WIDGET_PROPERTIES_FORWARD_BUTTON);
-
-        gconf_bridge_bind_property (
-                gconf_bridge_get (), GVA_GCONF_PROPERTIES_PAGE_KEY,
-                G_OBJECT (GVA_WIDGET_PROPERTIES_NOTEBOOK), "page");
+        g_settings_bind (
+                settings, GVA_SETTING_PROPERTIES_PAGE,
+                GVA_WIDGET_PROPERTIES_NOTEBOOK, "page",
+                G_SETTINGS_BIND_DEFAULT);
 
         g_signal_connect (
                 gtk_tree_view_get_selection (view), "changed",
                 G_CALLBACK (properties_selection_changed_cb), NULL);
 
+        g_signal_connect (
+                GVA_WIDGET_PROPERTIES_MUSIC_BUTTON, "notify::status",
+                G_CALLBACK (properties_notify_music_status_cb), NULL);
+
+        gtk_window_resize (
+                GTK_WINDOW (GVA_WIDGET_PROPERTIES_WINDOW),
+                g_settings_get_int (settings, "properties-width"),
+                g_settings_get_int (settings, "properties-height"));
+
+        if (g_settings_get_boolean (settings, "properties-maximized"))
+                gtk_window_maximize (GTK_WINDOW (GVA_WIDGET_PROPERTIES_WINDOW));
+
         font_name = gva_get_monospace_font_name ();
         desc = pango_font_description_from_string (font_name);
         gtk_widget_modify_font (text_view, desc);
         pango_font_description_free (desc);
         g_free (font_name);
 
-        settings = gtk_settings_get_default ();
-        g_object_get (settings, "color-hash", &color_hash, NULL);
+        gtk_settings = gtk_settings_get_default ();
+        g_object_get (gtk_settings, "color-hash", &color_hash, NULL);
         color = g_hash_table_lookup (color_hash, "tooltip_bg_color");
         widget = GVA_WIDGET_PROPERTIES_STATUS_EVENT_BOX;
         gtk_widget_modify_bg (widget, GTK_STATE_NORMAL, color);
         widget = GVA_WIDGET_PROPERTIES_STATUS_FRAME;
         gtk_widget_modify_bg (widget, GTK_STATE_NORMAL, color);
 
+#ifndef HAVE_GSTREAMER
+        gtk_widget_hide (GVA_WIDGET_PROPERTIES_MUSIC_TABLE);
+#endif
+
 #ifndef HISTORY_FILE
         /* Hide the history page if we have no history file. */
         notebook = GTK_NOTEBOOK (GVA_WIDGET_PROPERTIES_NOTEBOOK);
@@ -831,6 +873,7 @@ gva_properties_show_game (const gchar *game)
                 properties_update_cpu (game);
                 properties_update_header (model, &iter);
                 properties_update_history (model, &iter);
+                properties_update_music (game);
                 properties_update_sound (game);
                 properties_update_status (model, &iter);
                 properties_update_video (game);
@@ -840,19 +883,21 @@ gva_properties_show_game (const gchar *game)
 }
 
 /**
- * gva_properties_close_clicked_cb:
+ * gva_properties_hide_cb:
  * @window: the "Properties" window
  * @button: the "Close" button
  *
- * Handler for #GtkButton::clicked signals to the "Close" button.
+ * Handler for #GtkWidget::show signals to the "Properties" window.
  *
- * Hides @window.
+ * Stops in-game music clip.
  **/
 void
-gva_properties_close_clicked_cb (GtkWindow *window,
-                                 GtkButton *button)
+gva_properties_hide_cb (GtkWindow *window)
 {
-        gtk_widget_hide (GTK_WIDGET (window));
+        GvaMusicButton *music_button;
+
+        music_button = GVA_MUSIC_BUTTON (GVA_WIDGET_PROPERTIES_MUSIC_BUTTON);
+        gva_music_button_pause (music_button);
 }
 
 /**
@@ -861,10 +906,70 @@ gva_properties_close_clicked_cb (GtkWindow *window,
  *
  * Handler for #GtkWidget::show signals to the "Properties" window.
  *
- * Resets all scrolled windows to the top.
+ * Resets all scrolled windows to the top, and starts in-game music clip
+ * if the "auto-play" preference is enabled.
  **/
 void
 gva_properties_show_cb (GtkWindow *window)
 {
+        GvaMusicButton *music_button;
+
+        music_button = GVA_MUSIC_BUTTON (GVA_WIDGET_PROPERTIES_MUSIC_BUTTON);
+
+        if (gva_preferences_get_auto_play ())
+                gva_music_button_play (music_button);
+
         properties_scroll_to_top ();
 }
+
+/**
+ * gva_properties_configure_event_cb:
+ * @window: the "Properties" window
+ * @event: a #GdkEventConfigure
+ *
+ * Handler for #GtkWidget::configure-event signals to the "Properties"
+ * window.
+ *
+ * Saves the "Properties" window state to dconf.
+ *
+ * Returns: %FALSE always
+ **/
+gboolean
+gva_properties_configure_event_cb (GtkWindow *window,
+                                   GdkEventConfigure *event)
+{
+        gva_save_window_state (
+                window,
+                "properties-width",
+                "properties-height",
+                "properties-maximized",
+                NULL, NULL);
+
+        return FALSE;
+}
+
+/**
+ * gva_properties_window_state_event_cb:
+ * @window: the "Properties" window
+ * @event: a #GdkEventWindowState
+ *
+ * Handler for #GtkWidget::window-state-event signals to the "Properties"
+ * window.
+ *
+ * Saves the "Properties" window state to dconf.
+ *
+ * Returns: %FALSE always
+ **/
+gboolean
+gva_properties_window_state_event_cb (GtkWindow *window,
+                                      GdkEventWindowState *event)
+{
+        gva_save_window_state (
+                window,
+                "properties-width",
+                "properties-height",
+                "properties-maximized",
+                NULL, NULL);
+
+        return FALSE;
+}
