@@ -1,4 +1,4 @@
-/* Copyright 2007-2010 Matthew Barnes
+/* Copyright 2007-2011 Matthew Barnes
  *
  * This file is part of GNOME Video Arcade.
  *
@@ -31,14 +31,11 @@
 #include "gva-play-back.h"
 #include "gva-preferences.h"
 #include "gva-process.h"
+#include "gva-screen-saver.h"
 #include "gva-tree-view.h"
 #include "gva-util.h"
 #include "gva-wnck.h"
 
-#ifdef HAVE_DBUS
-#include "gva-dbus.h"
-#endif
-
 #define SQL_INSERT_LASTPLAYED \
         "INSERT INTO lastplayed VALUES ('%s', %" G_GINT64_FORMAT ")"
 
@@ -47,9 +44,8 @@
 
 static GtkBuilder *builder = NULL;
 static GtkUIManager *manager = NULL;
-static GtkActionGroup *standard_actions = NULL;
-static GtkActionGroup *lockable_actions = NULL;
 static gboolean initialized = FALSE;
+static GvaScreenSaver *screen_saver = NULL;
 
 /* About Dialog Information */
 static const gchar *authors[] =
@@ -58,7 +54,7 @@ static const gchar *authors[] =
         NULL
 };
 static const gchar *copyright =
-"Copyright \xC2\xA9 2007-2010 Matthew Barnes";
+"Copyright \xC2\xA9 2007-2011 Matthew Barnes";
 static const gchar *license =
 "GNOME Video Arcade is free software; you can redistribute it "
 "and/or modify it under the terms of the GNU General Public License "
@@ -73,6 +69,185 @@ static const gchar *license =
 "You should have received a copy of the GNU General Public License "
 "along with this program.  If not, see <http://www.gnu.org/licenses/>.";
 
+/**
+ * GVA_ACTION_ABOUT:
+ *
+ * Activation of this action displays the application's About dialog.
+ *
+ * Main menu item: Help -> About
+ **/
+
+/**
+ * GVA_ACTION_AUTO_PLAY:
+ *
+ * This toggle action tracks the user's preference for whether to
+ * automatically start playing a music clip from the selected game
+ * (if available) when the Properties window is open.
+ **/
+
+/**
+ * GVA_ACTION_AUTO_SAVE:
+ *
+ * This toggle action tracks the user's preference for whether to
+ * restore the emulated machine's previous state when starting a game.
+ **/
+
+/**
+ * GVA_ACTION_CONTENTS:
+ *
+ * Activation of this action opens the user manual for GNOME Video Arcade.
+ *
+ * Main menu item: Help -> Contents
+ **/
+
+/**
+ * GVA_ACTION_FULL_SCREEN:
+ *
+ * This toggle action tracks the user's preference for whether to
+ * start games in full screen mode.
+ **/
+
+/**
+ * GVA_ACTION_INSERT_FAVORITE:
+ *
+ * Activation of this action adds the currently selected game to the
+ * user's list of favorites.
+ *
+ * Main menu item: Game -> Add to Favorites
+ **/
+
+/**
+ * GVA_ACTION_NEXT_GAME:
+ *
+ * Activation of this action selects the next game, rolling over to
+ * the first game if necessary.
+ **/
+
+/**
+ * GVA_ACTION_PLAY_BACK:
+ *
+ * Activation of this action plays back the selected game recording.
+ **/
+
+/**
+ * GVA_ACTION_PREFERENCES:
+ *
+ * Activation of this action presents the "Preferences" window.
+ *
+ * Main menu item: Edit -> Preferences
+ **/
+
+/**
+ * GVA_ACTION_PREVIOUS_GAME:
+ *
+ * Activation of this action selects the previous game, rolling over to
+ * the last game if necessary.
+ **/
+
+/**
+ * GVA_ACTION_PROPERTIES:
+ *
+ * Activation of this action presents the "Properties" window.
+ *
+ * Main menu item: View -> Properties
+ **/
+
+/**
+ * GVA_ACTION_QUIT:
+ *
+ * Activation of this action initiates application shutdown.
+ *
+ * Main menu item: Game -> Quit
+ **/
+
+/**
+ * GVA_ACTION_RECORD:
+ *
+ * Activation of this action starts the selected game with MAME recording
+ * user inputs to a file.  The "Recorded Games" window will automatically
+ * be displayed when the user exits the game.
+ *
+ * Main menu item: Game -> Record
+ **/
+
+/**
+ * GVA_ACTION_REMOVE_COLUMN:
+ *
+ * Activation of this action removes the currently selected column from
+ * the game list.
+ **/
+
+/**
+ * GVA_ACTION_REMOVE_FAVORITE:
+ *
+ * Activation of this action removes the currently selected game from
+ * the user's list of favorites.
+ *
+ * Main menu item: Game -> Remove from Favorites
+ **/
+
+/**
+ * GVA_ACTION_SAVE_ERRORS:
+ *
+ * Activation of this action saves the errors from a ROM audit to a file.
+ **/
+
+/**
+ * GVA_ACTION_SEARCH:
+ *
+ * Activation of this action presents the "Search for Games" window.
+ *
+ * Main menu item: Edit -> Search...
+ **/
+
+/**
+ * GVA_ACTION_SHOW_CLONES:
+ *
+ * This toggle action tracks the user's preference for whether to
+ * show cloned games in the main window's game list.
+ **/
+
+/**
+ * GVA_ACTION_SHOW_PLAY_BACK:
+ *
+ * Activation of this action presents the "Recorded Games" window.
+ *
+ * Main menu item: Game -> Play Back...
+ **/
+
+/**
+ * GVA_ACTION_START:
+ *
+ * Activation of this action starts the selected game.
+ *
+ * Main menu item: Game -> Start
+ **/
+
+/**
+ * GVA_ACTION_VIEW_AVAILABLE:
+ *
+ * Activation of this action queries the database for all available games.
+ *
+ * Main menu item: View -> Available Games
+ **/
+
+/**
+ * GVA_ACTION_VIEW_FAVORITES:
+ *
+ * Activation of this action queries the database for the user's favorite
+ * games.
+ *
+ * Main menu item: View -> Favorite Games
+ **/
+
+/**
+ * GVA_ACTION_VIEW_RESULTS:
+ *
+ * Activation of this action executes a custom database query.
+ *
+ * Main menu item: View -> Search Results
+ **/
+
 static void
 log_lastplayed (GvaProcess *process,
                 gint status,
@@ -125,15 +300,8 @@ record_game_exited (GvaProcess *process,
         g_free (inpname);
 }
 
-/**
- * GVA_ACTION_ABOUT:
- *
- * Activation of this action displays the application's About dialog.
- *
- * Main menu item: Help -> About
- **/
-static void
-action_about_cb (GtkAction *action)
+void
+gva_action_about_cb (GtkAction *action)
 {
         GdkPixbuf *logo;
         GError *error = NULL;
@@ -177,57 +345,14 @@ action_add_column_cb (GtkAction *action,
         gtk_tree_view_column_set_visible (column, TRUE);
 }
 
-/**
- * GVA_ACTION_AUTO_PLAY:
- *
- * This toggle action tracks the user's preference for whether to
- * automatically start playing a music clip from the selected game
- * (if available) when the Properties window is open.
- **/
-
-/**
- * GVA_ACTION_AUTO_SAVE:
- *
- * This toggle action tracks the user's preference for whether to
- * restore the emulated machine's previous state when starting a game.
- **/
-
-/* No need for a callback function.  GConfBridge keeps the GConf key
- * synchronized with the toggle action's checked state. */
-
-/**
- * GVA_ACTION_CONTENTS:
- *
- * Activation of this action opens the user manual for GNOME Video Arcade.
- *
- * Main menu item: Help -> Contents
- **/
-static void
-action_contents_cb (GtkAction *action)
+void
+gva_action_contents_cb (GtkAction *action)
 {
         gva_help_display (GTK_WINDOW (GVA_WIDGET_MAIN_WINDOW), NULL);
 }
 
-/**
- * GVA_ACTION_FULL_SCREEN:
- *
- * This toggle action tracks the user's preference for whether to
- * start games in full screen mode.
- **/
-
-/* No need for a callback function.  GConfBridge keeps the GConf key
- * synchronized with the toggle action's checked state. */
-
-/**
- * GVA_ACTION_INSERT_FAVORITE:
- *
- * Activation of this action adds the currently selected game to the
- * user's list of favorites.
- *
- * Main menu item: Game -> Add to Favorites
- **/
-static void
-action_insert_favorite_cb (GtkAction *action)
+void
+gva_action_insert_favorite_cb (GtkAction *action)
 {
         GtkTreeModel *model;
         GtkTreePath *path;
@@ -254,14 +379,8 @@ action_insert_favorite_cb (GtkAction *action)
         gtk_action_set_visible (GVA_ACTION_REMOVE_FAVORITE, TRUE);
 }
 
-/**
- * GVA_ACTION_NEXT_GAME:
- *
- * Activation of this action selects the next game, rolling over to
- * the first game if necessary.
- **/
-static void
-action_next_game_cb (GtkAction *action)
+void
+gva_action_next_game_cb (GtkAction *action)
 {
         GtkTreeSelection *selection;
         GtkTreeModel *model;
@@ -288,13 +407,8 @@ action_next_game_cb (GtkAction *action)
         gtk_tree_path_free (path);
 }
 
-/**
- * GVA_ACTION_PLAY_BACK:
- *
- * Activation of this action plays back the selected game recording.
- **/
-static void
-action_play_back_cb (GtkAction *action)
+void
+gva_action_play_back_cb (GtkAction *action)
 {
         GtkWidget *widget;
         GvaProcess *process;
@@ -331,22 +445,27 @@ action_play_back_cb (GtkAction *action)
         process = gva_mame_playback_game (name, inpname, &error);
         gva_error_handle (&error);
 
-#ifdef HAVE_DBUS
         if (process != NULL)
         {
-                const gchar *reason;
+                if (gva_preferences_get_full_screen ())
+                {
+                        const gchar *reason;
 
-                /* Translators: This is passed through D-Bus as the
-                 * reason to inhibit GNOME screen saver. */
-                reason = _("Watching a fullscreen game");
-                gva_dbus_inhibit_screen_saver (process, reason, &error);
-                gva_error_handle (&error);
-        }
-#endif
+                        /* Translators: This is passed through D-Bus as
+                         * the reason to inhibit GNOME screen saver. */
+                        reason = _("Watching a fullscreen game");
+                        gva_screen_saver_set_reason (screen_saver, reason);
+                        gva_screen_saver_disable (screen_saver);
+
+                        g_signal_connect_data (
+                                process, "exited",
+                                G_CALLBACK (gva_screen_saver_enable),
+                                screen_saver, (GClosureNotify) NULL,
+                                G_CONNECT_AFTER | G_CONNECT_SWAPPED);
+                }
 
-        if (process != NULL)
-        {
                 gva_wnck_listen_for_new_window (process, name);
+
                 g_signal_connect_after (
                         process, "exited",
                         G_CALLBACK (log_lastplayed), g_strdup (name));
@@ -362,27 +481,14 @@ action_play_back_cb (GtkAction *action)
         g_list_free (list);
 }
 
-/**
- * GVA_ACTION_PREFERENCES:
- *
- * Activation of this action presents the "Preferences" window.
- *
- * Main menu item: Edit -> Preferences
- **/
-static void
-action_preferences_cb (GtkAction *action)
+void
+gva_action_preferences_cb (GtkAction *action)
 {
         gtk_window_present (GTK_WINDOW (GVA_WIDGET_PREFERENCES_WINDOW));
 }
 
-/**
- * GVA_ACTION_PREVIOUS_GAME:
- *
- * Activation of this action selects the previous game, rolling over to
- * the last game if necessary.
- **/
-static void
-action_previous_game_cb (GtkAction *action)
+void
+gva_action_previous_game_cb (GtkAction *action)
 {
         GtkTreeSelection *selection;
         GtkTreeModel *model;
@@ -409,44 +515,21 @@ action_previous_game_cb (GtkAction *action)
         gtk_tree_path_free (path);
 }
 
-/**
- * GVA_ACTION_PROPERTIES:
- *
- * Activation of this action presents the "Properties" window.
- *
- * Main menu item: View -> Properties
- **/
-static void
-action_properties_cb (GtkAction *action)
+void
+gva_action_properties_cb (GtkAction *action)
 {
         gtk_window_present (GTK_WINDOW (GVA_WIDGET_PROPERTIES_WINDOW));
 }
 
-/**
- * GVA_ACTION_QUIT:
- *
- * Activation of this action initiates application shutdown.
- *
- * Main menu item: Game -> Quit
- **/
-static void
-action_quit_cb (GtkAction *action)
+void
+gva_action_quit_cb (GtkAction *action)
 {
         gva_process_kill_all ();
         gtk_main_quit ();
 }
 
-/**
- * GVA_ACTION_RECORD:
- *
- * Activation of this action starts the selected game with MAME recording
- * user inputs to a file.  The "Recorded Games" window will automatically
- * be displayed when the user exits the game.
- *
- * Main menu item: Game -> Record
- **/
-static void
-action_record_cb (GtkAction *action)
+void
+gva_action_record_cb (GtkAction *action)
 {
         GtkWidget *widget;
         GvaProcess *process;
@@ -465,22 +548,27 @@ action_record_cb (GtkAction *action)
         process = gva_mame_record_game (name, inpname, &error);
         gva_error_handle (&error);
 
-#ifdef HAVE_DBUS
         if (process != NULL)
         {
-                const gchar *reason;
+                if (gva_preferences_get_full_screen ())
+                {
+                        const gchar *reason;
 
-                /* Translators: This is passed through D-Bus as the
-                 * reason to inhibit GNOME screen saver. */
-                reason = _("Recording a fullscreen game");
-                gva_dbus_inhibit_screen_saver (process, reason, &error);
-                gva_error_handle (&error);
-        }
-#endif
+                        /* Translators: This is passed through D-Bus as
+                         * the reason to inhibit GNOME screen saver. */
+                        reason = _("Recording a fullscreen game");
+                        gva_screen_saver_set_reason (screen_saver, reason);
+                        gva_screen_saver_disable (screen_saver);
+
+                        g_signal_connect_data (
+                                process, "exited",
+                                G_CALLBACK (gva_screen_saver_enable),
+                                screen_saver, (GClosureNotify) NULL,
+                                G_CONNECT_AFTER | G_CONNECT_SWAPPED);
+                }
 
-        if (process != NULL)
-        {
                 gva_wnck_listen_for_new_window (process, name);
+
                 g_signal_connect_after (
                         process, "exited",
                         G_CALLBACK (log_lastplayed), g_strdup (name));
@@ -495,14 +583,8 @@ action_record_cb (GtkAction *action)
         g_free (inpname);
 }
 
-/**
- * GVA_ACTION_REMOVE_COLUMN:
- *
- * Activation of this action removes the currently selected column from
- * the game list.
- **/
-static void
-action_remove_column_cb (GtkAction *action)
+void
+gva_action_remove_column_cb (GtkAction *action)
 {
         GtkTreeViewColumn *column;
         GtkTreeView *view;
@@ -515,16 +597,8 @@ action_remove_column_cb (GtkAction *action)
         gtk_tree_view_column_set_visible (column, FALSE);
 }
 
-/**
- * GVA_ACTION_REMOVE_FAVORITE:
- *
- * Activation of this action removes the currently selected game from
- * the user's list of favorites.
- *
- * Main menu item: Game -> Remove from Favorites
- **/
-static void
-action_remove_favorite_cb (GtkAction *action)
+void
+gva_action_remove_favorite_cb (GtkAction *action)
 {
         GtkTreeModel *model;
         GtkTreePath *path;
@@ -551,81 +625,55 @@ action_remove_favorite_cb (GtkAction *action)
         gtk_action_set_visible (GVA_ACTION_REMOVE_FAVORITE, FALSE);
 }
 
-/**
- * GVA_ACTION_SAVE_ERRORS:
- *
- * Activation of this action saves the errors from a ROM audit to a file.
- **/
-static void
-action_save_errors_cb (GtkAction *action)
+void
+gva_action_save_errors_cb (GtkAction *action)
 {
         gva_audit_save_errors ();
 }
 
-/**
- * GVA_ACTION_SEARCH:
- *
- * Activation of this action presents the "Search for Games" window.
- *
- * Main menu item: Edit -> Search...
- **/
-static void
-action_search_cb (GtkAction *action)
+void
+gva_action_search_cb (GtkAction *action)
 {
         GtkWidget *widget;
 
-        gtk_widget_show (GVA_WIDGET_MAIN_SEARCH_HBOX);
-
         widget = GVA_WIDGET_MAIN_SEARCH_ENTRY;
         gtk_widget_grab_focus (widget);
+
+        /* Show the search bar -after- grabbing focus or else
+         * Edit->Search (from the main menu) will immediately
+         * hide the search bar again. */
+        gtk_widget_show (GVA_WIDGET_MAIN_SEARCH_HBOX);
+
+        /* This triggers the entry completion. */
         g_signal_emit_by_name (widget, "changed");
+
         gtk_cell_editable_start_editing (GTK_CELL_EDITABLE (widget), NULL);
 }
 
-/**
- * GVA_ACTION_SHOW_CLONES:
- *
- * This toggle action tracks the user's preference for whether to
- * show cloned games in the main window's game list.
- **/
-static void
-action_show_clones_cb (GtkToggleAction *action)
+void
+gva_action_show_clones_cb (GtkAction *action)
 {
         GError *error = NULL;
 
         /* This is a bit of a hack.  We want to instantly apply the
          * user preference, but not while loading the initial value
-         * from GConf.  So we desensitize the action until we're up
-         * and running, and use that to decide what to do here. */
-        if (gtk_action_is_sensitive (GTK_ACTION (action)))
+         * from GSettings.  So we desensitize the action until we're
+         * up and running, and use that to decide what to do here. */
+        if (gtk_action_is_sensitive (action))
         {
                 gva_tree_view_update (&error);
                 gva_error_handle (&error);
         }
 }
 
-/**
- * GVA_ACTION_SHOW_PLAY_BACK:
- *
- * Activation of this action presents the "Recorded Games" window.
- *
- * Main menu item: Game -> Play Back...
- **/
-static void
-action_show_play_back_cb (GtkAction *action)
+void
+gva_action_show_play_back_cb (GtkAction *action)
 {
         gva_play_back_show (NULL);
 }
 
-/**
- * GVA_ACTION_START:
- *
- * Activation of this action starts the selected game.
- *
- * Main menu item: Game -> Start
- **/
-static void
-action_start_cb (GtkAction *action)
+void
+gva_action_start_cb (GtkAction *action)
 {
         GtkWidget *widget;
         GvaProcess *process;
@@ -644,22 +692,27 @@ action_start_cb (GtkAction *action)
         process = gva_mame_run_game (name, &error);
         gva_error_handle (&error);
 
-#ifdef HAVE_DBUS
         if (process != NULL)
         {
-                const gchar *reason;
+                if (gva_preferences_get_full_screen ())
+                {
+                        const gchar *reason;
 
-                /* Translators: This is passed through D-Bus as the
-                 * reason to inhibit GNOME screen saver. */
-                reason = _("Playing a fullscreen game");
-                gva_dbus_inhibit_screen_saver (process, reason, &error);
-                gva_error_handle (&error);
-        }
-#endif
+                        /* Translators: This is passed through D-Bus as the
+                         * reason to inhibit GNOME screen saver. */
+                        reason = _("Playing a fullscreen game");
+                        gva_screen_saver_set_reason (screen_saver, reason);
+                        gva_screen_saver_disable (screen_saver);
+
+                        g_signal_connect_data (
+                                process, "exited",
+                                G_CALLBACK (gva_screen_saver_enable),
+                                screen_saver, (GClosureNotify) NULL,
+                                G_CONNECT_AFTER | G_CONNECT_SWAPPED);
+                }
 
-        if (process != NULL)
-        {
                 gva_wnck_listen_for_new_window (process, name);
+
                 g_signal_connect_after (
                         process, "exited",
                         G_CALLBACK (log_lastplayed), g_strdup (name));
@@ -669,33 +722,9 @@ action_start_cb (GtkAction *action)
         }
 }
 
-/**
- * GVA_ACTION_VIEW_AVAILABLE:
- *
- * Activation of this action queries the database for all available games.
- *
- * Main menu item: View -> Available Games
- **/
-
-/**
- * GVA_ACTION_VIEW_FAVORITES:
- *
- * Activation of this action queries the database for the user's favorite
- * games.
- *
- * Main menu item: View -> Favorite Games
- **/
-
-/**
- * GVA_ACTION_VIEW_RESULTS:
- *
- * Activation of this action executes a custom database query.
- *
- * Main menu item: View -> Search Results
- **/
-static void
-action_view_changed_cb (GtkRadioAction *action,
-                        GtkRadioAction *current)
+void
+gva_action_view_changed_cb (GtkRadioAction *action,
+                            GtkRadioAction *current)
 {
         GError *error = NULL;
 
@@ -703,231 +732,6 @@ action_view_changed_cb (GtkRadioAction *action,
         gva_error_handle (&error);
 }
 
-static GtkActionEntry standard_entries[] =
-{
-        { "about",
-          GTK_STOCK_ABOUT,
-          N_("_About"),
-          NULL,
-          N_("Show information about the application"),
-          G_CALLBACK (action_about_cb) },
-
-        { "contents",
-          GTK_STOCK_HELP,
-          N_("_Contents"),
-          NULL,
-          N_("Open the help documentation"),
-          G_CALLBACK (action_contents_cb) },
-
-        { "preferences",
-          GTK_STOCK_PREFERENCES,
-          N_("_Preferences"),
-          NULL,
-          N_("Configure the application"),
-          G_CALLBACK (action_preferences_cb) },
-
-        { "quit",
-          GTK_STOCK_QUIT,
-          N_("_Quit"),
-          NULL,
-          N_("Quit the application"),
-          G_CALLBACK (action_quit_cb) },
-
-        { "add-column-menu",
-          NULL,
-          N_("_Add Column"),
-          NULL,
-          NULL,
-          NULL },
-
-        { "edit-menu",
-          NULL,
-          N_("_Edit"),
-          NULL,
-          NULL,
-          NULL },
-
-        { "game-menu",
-          NULL,
-          N_("_Game"),
-          NULL,
-          NULL,
-          NULL },
-
-        { "help-menu",
-          NULL,
-          N_("_Help"),
-          NULL,
-          NULL,
-          NULL },
-
-        { "view-menu",
-          NULL,
-          N_("_View"),
-          NULL,
-          NULL,
-          NULL }
-};
-
-static GtkActionEntry lockable_entries[] =
-{
-        { "insert-favorite",
-          GTK_STOCK_ADD,
-          N_("Add to _Favorites"),
-          "<Control>plus",
-          N_("Add the selected game to my list of favorites"),
-          G_CALLBACK (action_insert_favorite_cb) },
-
-        { "next-game",
-          GTK_STOCK_GO_FORWARD,
-          NULL,
-          "<Alt>rightarrow",
-          N_("Show next game"),
-          G_CALLBACK (action_next_game_cb) },
-
-        { "play-back",
-          GTK_STOCK_MEDIA_PLAY,
-          N_("Play _Back..."),
-          NULL,
-          N_("Play back the selected game recording"),
-          G_CALLBACK (action_play_back_cb) },
-
-        { "previous-game",
-          GTK_STOCK_GO_BACK,
-          NULL,
-          "<Alt>leftarrow",
-          N_("Show previous game"),
-          G_CALLBACK (action_previous_game_cb) },
-
-        { "properties",
-          GTK_STOCK_PROPERTIES,
-          N_("_Properties"),
-          "<Control>p",
-          N_("Show information about the selected game"),
-          G_CALLBACK (action_properties_cb) },
-
-        { "record",
-          GTK_STOCK_MEDIA_RECORD,
-          N_("_Record"),
-          "<Control>r",
-          N_("Start the selected game and record keypresses to a file"),
-          G_CALLBACK (action_record_cb) },
-
-        { "remove-column",
-          NULL,
-          "Fake Label",  /* label is set dynamically */
-          NULL,
-          NULL,          /* tooltip is set dynamically */
-          G_CALLBACK (action_remove_column_cb) },
-
-        { "remove-favorite",
-          GTK_STOCK_REMOVE,
-          N_("Remove from _Favorites"),
-          "<Control>minus",
-          N_("Remove the selected game from my list of favorites"),
-          G_CALLBACK (action_remove_favorite_cb) },
-
-        { "save-errors",
-          GTK_STOCK_SAVE_AS,
-          N_("Save _As..."),
-          NULL,
-          N_("Save ROM errors to a file"),
-          G_CALLBACK (action_save_errors_cb) },
-
-        { "search",
-          GTK_STOCK_FIND,
-          N_("S_earch..."),
-          NULL,
-          N_("Show a custom list of games"),
-          G_CALLBACK (action_search_cb) },
-
-        { "show-play-back",
-          GTK_STOCK_MEDIA_PLAY,
-          N_("Play _Back..."),
-          NULL,
-          N_("Play back a previously recorded game"),
-          G_CALLBACK (action_show_play_back_cb) },
-
-        { "start",
-          GTK_STOCK_EXECUTE,
-          N_("_Start"),
-          "<Control>s",
-          N_("Start the selected game"),
-          G_CALLBACK (action_start_cb) }
-};
-
-static GtkToggleActionEntry standard_toggle_entries[] =
-{
-        { "auto-play",
-          NULL,
-          N_("Play music _automatically"),
-          NULL,
-          N_("Automatically play a music clip from the selected game"),
-          NULL,     /* GConfBridge monitors the state */
-          FALSE },  /* GConf overrides this */
-
-        { "auto-save",
-          NULL,
-          N_("_Restore previous state when starting a game"),
-          NULL,
-          NULL,
-          NULL,     /* GConfBridge monitors the state */
-          FALSE },  /* GConf overrides this */
-
-        { "full-screen",
-          NULL,
-          N_("Start games in _fullscreen mode"),
-          NULL,
-          NULL,
-          NULL,     /* GConfBridge monitors the state */
-          FALSE }   /* GConf overrides this */
-};
-
-static GtkToggleActionEntry lockable_toggle_entries[] =
-{
-        { "show-clones",
-          NULL,
-          N_("Show _alternate versions of original games"),
-          NULL,
-          NULL,
-          G_CALLBACK (action_show_clones_cb),
-          FALSE }   /* GConf overrides this */
-};
-
-static GtkRadioActionEntry view_radio_entries[] =
-{
-        /* This is a bogus view that we switch away from on startup.
-         * It ensures that restoring the previous session's view from
-         * GConf always triggers a GtkRadioAction::changed emission. */
-        { "view-initial",
-          NULL,
-          NULL,
-          NULL,
-          NULL,
-          -1 },
-
-        { "view-available",
-          NULL,
-          N_("_Available Games"),
-          "<Control>1",
-          N_("Show all available games"),
-          0 },
-
-        { "view-favorites",
-          NULL,
-          N_("_Favorite Games"),
-          "<Control>2",
-          N_("Only show my favorite games"),
-          1 },
-
-        { "view-results",
-          NULL,
-          N_("Search _Results"),
-          "<Control>3",
-          N_("Show my search results"),
-          2 }
-};
-
 static void
 ui_column_notify_visible_cb (GtkTreeViewColumn *column,
                              GParamSpec *pspec,
@@ -955,6 +759,7 @@ ui_sort_columns (GtkTreeViewColumn *column1,
 static void
 ui_init (void)
 {
+        GObject *object;
         gchar *filename;
         GError *error = NULL;
 
@@ -962,35 +767,8 @@ ui_init (void)
          * when we use the GVA_WIDGET_MAIN_WINDOW macro below. */
         initialized = TRUE;
 
-        standard_actions = gtk_action_group_new ("standard");
-        gtk_action_group_set_translation_domain (
-                standard_actions, GETTEXT_PACKAGE);
-        gtk_action_group_add_actions (
-                standard_actions, standard_entries,
-                G_N_ELEMENTS (standard_entries), NULL);
-        gtk_action_group_add_toggle_actions (
-                standard_actions, standard_toggle_entries,
-                G_N_ELEMENTS (standard_toggle_entries), NULL);
-
-        lockable_actions = gtk_action_group_new ("lockable");
-        gtk_action_group_set_translation_domain (
-                lockable_actions, GETTEXT_PACKAGE);
-        gtk_action_group_add_actions (
-                lockable_actions, lockable_entries,
-                G_N_ELEMENTS (lockable_entries), NULL);
-        gtk_action_group_add_toggle_actions (
-                lockable_actions, lockable_toggle_entries,
-                G_N_ELEMENTS (lockable_toggle_entries), NULL);
-        gtk_action_group_add_radio_actions (
-                lockable_actions, view_radio_entries,
-                G_N_ELEMENTS (view_radio_entries),
-                -1, G_CALLBACK (action_view_changed_cb), NULL);
-
         manager = gtk_ui_manager_new ();
 
-        gtk_ui_manager_insert_action_group (manager, standard_actions, 0);
-        gtk_ui_manager_insert_action_group (manager, lockable_actions, 0);
-
         filename = gva_find_data_file (PACKAGE ".builder");
         if (filename != NULL && error == NULL)
         {
@@ -1020,6 +798,14 @@ ui_init (void)
 
         if (builder == NULL || manager == NULL)
                 g_error ("%s", _("Failed to initialize user interface"));
+
+        object = gtk_builder_get_object (builder, "standard-actions");
+        gtk_ui_manager_insert_action_group (
+                manager, GTK_ACTION_GROUP (object), 0);
+
+        object = gtk_builder_get_object (builder, "lockable-actions");
+        gtk_ui_manager_insert_action_group (
+                manager, GTK_ACTION_GROUP (object), 0);
 }
 
 /**
@@ -1037,19 +823,23 @@ GtkAction *
 gva_ui_get_action (const gchar *action_name)
 {
         GtkAction *action;
+        GList *list, *iter;
 
         g_return_val_if_fail (action_name != NULL, NULL);
 
         if (G_UNLIKELY (!initialized))
                 ui_init ();
 
-        action = gtk_action_group_get_action (standard_actions, action_name);
-        if (action != NULL)
-                return action;
+        list = gtk_ui_manager_get_action_groups (manager);
+        for (iter = list; iter != NULL; iter = g_list_next (iter))
+        {
+                GtkActionGroup *group;
 
-        action = gtk_action_group_get_action (lockable_actions, action_name);
-        if (action != NULL)
-                return action;
+                group = GTK_ACTION_GROUP (iter->data);
+                action = gtk_action_group_get_action (group, action_name);
+                if (action != NULL)
+                        return action;
+        }
 
         g_error ("No action named '%s'", action_name);
 }
@@ -1077,6 +867,7 @@ gva_ui_get_widget (const gchar *widget_name)
 
         object = gtk_builder_get_object (builder, widget_name);
         g_assert (object != NULL);
+
         return GTK_WIDGET (object);
 }
 
@@ -1118,11 +909,16 @@ gva_ui_get_managed_widget (const gchar *widget_path)
 void
 gva_ui_add_column_actions (GtkTreeView *view)
 {
+        GObject *object;
+        GtkActionGroup *action_group;
         GList *list;
         guint merge_id;
 
         g_return_if_fail (GTK_IS_TREE_VIEW (view));
 
+        object = gtk_builder_get_object (builder, "standard-actions");
+        action_group = GTK_ACTION_GROUP (object);
+
         list = gtk_tree_view_get_columns (view);
         list = g_list_sort (list, (GCompareFunc) ui_sort_columns);
         merge_id = gtk_ui_manager_new_merge_id (manager);
@@ -1150,7 +946,7 @@ gva_ui_add_column_actions (GtkTreeView *view)
 
                 action = gtk_action_new (
                         action_name, action_label, action_tooltip, NULL);
-                gtk_action_group_add_action (standard_actions, action);
+                gtk_action_group_add_action (action_group, action);
 
                 visible = gtk_tree_view_column_get_visible (column);
                 gtk_action_set_visible (action, !visible);
@@ -1186,11 +982,17 @@ gva_ui_add_column_actions (GtkTreeView *view)
 void
 gva_ui_lock (void)
 {
+        GObject *object;
+        GtkActionGroup *action_group;
+
+        object = gtk_builder_get_object (builder, "lockable-actions");
+        action_group = GTK_ACTION_GROUP (object);
+
         /* Hide secondary windows that may interfere. */
         gtk_widget_hide (GVA_WIDGET_PLAY_BACK_WINDOW);
         gtk_widget_hide (GVA_WIDGET_PROPERTIES_WINDOW);
 
-        gtk_action_group_set_sensitive (lockable_actions, FALSE);
+        gtk_action_group_set_sensitive (action_group, FALSE);
         gtk_widget_set_sensitive (GVA_WIDGET_MAIN_TREE_VIEW, FALSE);
 }
 
@@ -1202,6 +1004,23 @@ gva_ui_lock (void)
 void
 gva_ui_unlock (void)
 {
-        gtk_action_group_set_sensitive (lockable_actions, TRUE);
+        GObject *object;
+        GtkActionGroup *action_group;
+
+        object = gtk_builder_get_object (builder, "lockable-actions");
+        action_group = GTK_ACTION_GROUP (object);
+
+        gtk_action_group_set_sensitive (action_group, TRUE);
         gtk_widget_set_sensitive (GVA_WIDGET_MAIN_TREE_VIEW, TRUE);
 }
+
+/**
+ * gva_ui_init:
+ *
+ * Initializes the screen saver inhibitor.
+ **/
+void
+gva_ui_init (void)
+{
+        screen_saver = gva_screen_saver_new ();
+}
