@@ -1,4 +1,4 @@
-/* Copyright 2007-2009 Matthew Barnes
+/* Copyright 2007-2011 Matthew Barnes
  *
  * This file is part of GNOME Video Arcade.
  *
@@ -31,6 +31,7 @@
 
 /* Actions */
 #define GVA_ACTION_ABOUT                (gva_ui_get_action ("about"))
+#define GVA_ACTION_AUTO_PLAY            (gva_ui_get_action ("auto-play"))
 #define GVA_ACTION_AUTO_SAVE            (gva_ui_get_action ("auto-save"))
 #define GVA_ACTION_CONTENTS             (gva_ui_get_action ("contents"))
 #define GVA_ACTION_FULL_SCREEN          (gva_ui_get_action ("full-screen"))
@@ -142,6 +143,14 @@
         (gva_ui_get_widget ("properties-imperfect-graphic-label"))
 #define GVA_WIDGET_PROPERTIES_IMPERFECT_SOUND_LABEL \
         (gva_ui_get_widget ("properties-imperfect-sound-label"))
+#define GVA_WIDGET_PROPERTIES_MUSIC_AUTO_PLAY \
+        (gva_ui_get_widget ("properties-music-auto-play"))
+#define GVA_WIDGET_PROPERTIES_MUSIC_BUTTON \
+        (gva_ui_get_widget ("properties-music-button"))
+#define GVA_WIDGET_PROPERTIES_MUSIC_STATUS \
+        (gva_ui_get_widget ("properties-music-status"))
+#define GVA_WIDGET_PROPERTIES_MUSIC_TABLE \
+        (gva_ui_get_widget ("properties-music-table"))
 #define GVA_WIDGET_PROPERTIES_NOTEBOOK \
         (gva_ui_get_widget ("properties-notebook"))
 #define GVA_WIDGET_PROPERTIES_ORIGINAL_LINKS \
@@ -179,6 +188,32 @@ GtkAction *     gva_ui_get_action               (const gchar *action_name);
 GtkWidget *     gva_ui_get_widget               (const gchar *widget_name);
 GtkWidget *     gva_ui_get_managed_widget       (const gchar *widget_path);
 void            gva_ui_add_column_actions       (GtkTreeView *view);
+void            gva_ui_lock                     (void);
+void            gva_ui_unlock                   (void);
+void            gva_ui_init                     (void);
+
+/* GtkAction callbacks */
+
+void            gva_action_about_cb             (GtkAction *action);
+void            gva_action_contents_cb          (GtkAction *action);
+void            gva_action_insert_favorite_cb   (GtkAction *action);
+void            gva_action_next_game_cb         (GtkAction *action);
+void            gva_action_play_back_cb         (GtkAction *action);
+void            gva_action_preferences_cb       (GtkAction *action);
+void            gva_action_previous_game_cb     (GtkAction *action);
+void            gva_action_properties_cb        (GtkAction *action);
+void            gva_action_quit_cb              (GtkAction *action);
+void            gva_action_record_cb            (GtkAction *action);
+void            gva_action_remove_column_cb     (GtkAction *action);
+void            gva_action_remove_favorite_cb   (GtkAction *action);
+void            gva_action_save_errors_cb       (GtkAction *action);
+void            gva_action_search_cb            (GtkAction *action);
+void            gva_action_show_clones_cb       (GtkAction *action);
+void            gva_action_show_play_back_cb    (GtkAction *action);
+void            gva_action_start_cb             (GtkAction *action);
+
+void            gva_action_view_changed_cb      (GtkRadioAction *action,
+                                                 GtkRadioAction *current);
 
 G_END_DECLS
 
