@@ -1,4 +1,4 @@
-/* Copyright 2007-2010 Matthew Barnes
+/* Copyright 2007-2011 Matthew Barnes
  *
  * This file is part of GNOME Video Arcade.
  *
@@ -25,9 +25,6 @@
 
 #define DEFAULT_MONOSPACE_FONT_NAME     "Monospace 10"
 
-#define GCONF_MONOSPACE_FONT_NAME_KEY \
-        "/desktop/gnome/interface/monospace_font_name"
-
 /* Command Line Options */
 gboolean opt_build_database;
 gchar *opt_inspect;
@@ -222,21 +219,15 @@ gva_get_last_version (void)
 
         if (G_UNLIKELY (first_time))
         {
-                GConfClient *client;
-                GError *error = NULL;
+                GSettings *settings;
 
-                client = gconf_client_get_default ();
+                settings = gva_get_settings ();
 
-                last_version = gconf_client_get_string (
-                        client, GVA_GCONF_VERSION_KEY, &error);
-                gva_error_handle (&error);
+                last_version = g_settings_get_string (
+                        settings, GVA_SETTING_VERSION);
 
-                gconf_client_set_string (
-                        client, GVA_GCONF_VERSION_KEY,
-                        PACKAGE_VERSION, &error);
-                gva_error_handle (&error);
-
-                g_object_unref (client);
+                g_settings_set_string (
+                        settings, GVA_SETTING_VERSION, PACKAGE_VERSION);
 
                 first_time = FALSE;
         }
@@ -255,15 +246,12 @@ gva_get_last_version (void)
 gchar *
 gva_get_monospace_font_name (void)
 {
-        GConfClient *client;
+        GSettings *settings;
         gchar *font_name;
-        GError *error = NULL;
 
-        client = gconf_client_get_default ();
-        font_name = gconf_client_get_string (
-                client, GCONF_MONOSPACE_FONT_NAME_KEY, &error);
-        gva_error_handle (&error);
-        g_object_unref (client);
+        settings = g_settings_new ("org.gnome.desktop.interface");
+        font_name = g_settings_get_string (settings, "monospace-font-name");
+        g_object_unref (settings);
 
         /* Fallback to a reasonable default. */
         if (font_name == NULL)
@@ -272,6 +260,26 @@ gva_get_monospace_font_name (void)
         return font_name;
 }
 
+/**
+ * gva_get_settings:
+ *
+ * Returns the #GSettings object loaded with the schema for
+ * <emphasis>GNOME Video Arcade</emphasis>.
+ *
+ * Returns: the #GSettings object for
+ *          <emphasis>GNOME Video Arcade</emphasis>
+ **/
+GSettings *
+gva_get_settings (void)
+{
+        static GSettings *settings = NULL;
+
+        if (G_UNLIKELY (settings == NULL))
+                settings = g_settings_new ("org.gnome.VideoArcade");
+
+        return settings;
+}
+
 /**
  * gva_get_time_elapsed:
  * @start_time: a start time
@@ -369,6 +377,66 @@ exit:
         g_string_free (uri, TRUE);
 }
 
+/**
+ * gva_save_window_state:
+ * @window: a #GtkWindow
+ * @width_key: name of the window width integer setting, or %NULL
+ * @height_key: name of the window height integer setting, or %NULL
+ * @maximized_key: name of the window maximized boolean setting, or %NULL
+ * @x_key: name of the window X-position integer setting, or %NULL
+ * @y_key: name of the window Y-position integer setting, or %NULL
+ *
+ * Writes the dimensions, position and maximize state of @window to the
+ * given #GSettings keys.  If a key name argument is %NULL, the function
+ * will skip writing a value to that setting.
+ **/
+void
+gva_save_window_state (GtkWindow *window,
+                       const gchar *width_key,
+                       const gchar *height_key,
+                       const gchar *maximized_key,
+                       const gchar *x_key,
+                       const gchar *y_key)
+{
+        GSettings *settings;
+        GdkWindow *gdk_window;
+        GdkWindowState state;
+        gboolean maximized;
+
+        g_return_if_fail (GTK_IS_WINDOW (window));
+
+        settings = gva_get_settings ();
+
+        gdk_window = gtk_widget_get_window (GTK_WIDGET (window));
+        state = gdk_window_get_state (gdk_window);
+        maximized = ((state & GDK_WINDOW_STATE_MAXIMIZED) != 0);
+
+        if (!maximized)
+        {
+                gint x, y;
+                gint width;
+                gint height;
+
+                gtk_window_get_position (window, &x, &y);
+                gtk_window_get_size (window, &width, &height);
+
+                if (x_key != NULL)
+                        g_settings_set_int (settings, x_key, x);
+
+                if (y_key != NULL)
+                        g_settings_set_int (settings, y_key, y);
+
+                if (width_key != NULL)
+                        g_settings_set_int (settings, width_key, width);
+
+                if (height_key != NULL)
+                        g_settings_set_int (settings, height_key, height);
+        }
+
+        if (maximized_key != NULL)
+                g_settings_set_boolean (settings, maximized_key, maximized);
+}
+
 /**
  * gva_search_collate_key:
  * @string: a string
@@ -419,7 +487,7 @@ gva_search_collate_key (const gchar *string)
  * @error: return location for a #GError, or %NULL
  *
  * Convenience function that passes @command_line to g_shell_parse_argv(),
- * and passes the resulting argument list to gdk_spawn_on_screen_with_pipes().
+ * and passes the resulting argument list to g_spawn_async_with_pipes().
  * If an error occurs, it results %FALSE and sets @error.
  *
  * Returns: %TRUE if successful, %FALSE if an error occurred
@@ -440,11 +508,10 @@ gva_spawn_with_pipes (const gchar *command_line,
         if (!g_shell_parse_argv (command_line, NULL, &argv, error))
                 return FALSE;
 
-        success = gdk_spawn_on_screen_with_pipes (
-                gdk_screen_get_default (), NULL, argv, NULL,
-                G_SPAWN_DO_NOT_REAP_CHILD, NULL, NULL, child_pid,
-                standard_input, standard_output, standard_error,
-                error);
+        success = g_spawn_async_with_pipes (
+                NULL, argv, NULL, G_SPAWN_DO_NOT_REAP_CHILD, NULL,
+                NULL, child_pid, standard_input, standard_output,
+                standard_error, error);
 
         g_strfreev (argv);
 
