@@ -1,4 +1,4 @@
-/* Copyright 2007-2009 Matthew Barnes
+/* Copyright 2007-2011 Matthew Barnes
  *
  * This file is part of GNOME Video Arcade.
  *
@@ -43,6 +43,8 @@ G_BEGIN_DECLS
  *      Print all communication between GVA and MAME.
  * @GVA_DEBUG_INP:
  *      Print information about input files.
+ * @GVA_DEBUG_GST:
+ *      Print GStreamer activity.
  *
  * These flags indicate which types of debugging messages will be triggered
  * at runtime. Debugging messages can be triggered by setting the GVA_DEBUG
@@ -50,11 +52,12 @@ G_BEGIN_DECLS
  **/
 typedef enum
 {
-        GVA_DEBUG_NONE = 0,
-        GVA_DEBUG_MAME = 1 << 0,
-        GVA_DEBUG_SQL  = 1 << 1,
-        GVA_DEBUG_IO   = 1 << 2,
-        GVA_DEBUG_INP  = 1 << 3
+        GVA_DEBUG_NONE  = 0,
+        GVA_DEBUG_MAME  = 1 << (G_LOG_LEVEL_USER_SHIFT + 0),
+        GVA_DEBUG_SQL   = 1 << (G_LOG_LEVEL_USER_SHIFT + 1),
+        GVA_DEBUG_IO    = 1 << (G_LOG_LEVEL_USER_SHIFT + 2),
+        GVA_DEBUG_INP   = 1 << (G_LOG_LEVEL_USER_SHIFT + 3),
+        GVA_DEBUG_GST   = 1 << (G_LOG_LEVEL_USER_SHIFT + 4)
 } GvaDebugFlags;
 
 gchar *         gva_choose_inpname              (const gchar *game);
@@ -62,11 +65,18 @@ gchar *         gva_find_data_file              (const gchar *basename);
 GvaDebugFlags   gva_get_debug_flags             (void);
 const gchar *   gva_get_last_version            (void);
 gchar *         gva_get_monospace_font_name     (void);
+GSettings *     gva_get_settings                (void);
 void            gva_get_time_elapsed            (GTimeVal *start_time,
                                                  GTimeVal *time_elapsed);
 const gchar *   gva_get_user_data_dir           (void);
 void            gva_help_display                (GtkWindow *parent,
                                                  const gchar *link_id);
+void            gva_save_window_state           (GtkWindow *window,
+                                                 const gchar *width_key,
+                                                 const gchar *height_key,
+                                                 const gchar *maximized_key,
+                                                 const gchar *x_key,
+                                                 const gchar *y_key);
 gchar *         gva_search_collate_key          (const gchar *string);
 gboolean        gva_spawn_with_pipes            (const gchar *command_line,
                                                  GPid *child_pid,
